pub struct DeviceGetDvfsInfoResponse {
pub status: i32,
pub info: Option<Box<OperatingPoint>>,
}Fields
status: i32info: Option<Box<OperatingPoint>>Trait Implementations
Sourceimpl Clone for DeviceGetDvfsInfoResponse
impl Clone for DeviceGetDvfsInfoResponse
Sourcefn clone(&self) -> DeviceGetDvfsInfoResponse
fn clone(&self) -> DeviceGetDvfsInfoResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceGetDvfsInfoResponse
impl Debug for DeviceGetDvfsInfoResponse
Sourceimpl<D: ResourceDialect> Decode<DeviceGetDvfsInfoResponse, D> for DeviceGetDvfsInfoResponse
impl<D: ResourceDialect> Decode<DeviceGetDvfsInfoResponse, D> for DeviceGetDvfsInfoResponse
Sourceimpl<D: ResourceDialect> Encode<DeviceGetDvfsInfoResponse, D> for &DeviceGetDvfsInfoResponse
impl<D: ResourceDialect> Encode<DeviceGetDvfsInfoResponse, D> for &DeviceGetDvfsInfoResponse
Sourceimpl<D: ResourceDialect, T0: Encode<i32, D>, T1: Encode<Boxed<OperatingPoint>, D>> Encode<DeviceGetDvfsInfoResponse, D> for (T0, T1)
impl<D: ResourceDialect, T0: Encode<i32, D>, T1: Encode<Boxed<OperatingPoint>, D>> Encode<DeviceGetDvfsInfoResponse, D> for (T0, T1)
impl Eq for DeviceGetDvfsInfoResponse
Sourceimpl Hash for DeviceGetDvfsInfoResponse
impl Hash for DeviceGetDvfsInfoResponse
Sourceimpl Ord for DeviceGetDvfsInfoResponse
impl Ord for DeviceGetDvfsInfoResponse
Sourcefn cmp(&self, other: &DeviceGetDvfsInfoResponse) -> Ordering
fn cmp(&self, other: &DeviceGetDvfsInfoResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceGetDvfsInfoResponse
impl PartialEq for DeviceGetDvfsInfoResponse
Sourcefn eq(&self, other: &DeviceGetDvfsInfoResponse) -> bool
fn eq(&self, other: &DeviceGetDvfsInfoResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceGetDvfsInfoResponse
impl PartialOrd for DeviceGetDvfsInfoResponse
impl Persistable for DeviceGetDvfsInfoResponse
impl StructuralPartialEq for DeviceGetDvfsInfoResponse
Sourceimpl TypeMarker for DeviceGetDvfsInfoResponse
impl TypeMarker for DeviceGetDvfsInfoResponse
Sourcetype Owned = DeviceGetDvfsInfoResponse
type Owned = DeviceGetDvfsInfoResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for DeviceGetDvfsInfoResponse
impl ValueTypeMarker for DeviceGetDvfsInfoResponse
Sourcetype Borrowed<'a> = &'a DeviceGetDvfsInfoResponse
type Borrowed<'a> = &'a DeviceGetDvfsInfoResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for DeviceGetDvfsInfoResponse
impl RefUnwindSafe for DeviceGetDvfsInfoResponse
impl Send for DeviceGetDvfsInfoResponse
impl Sync for DeviceGetDvfsInfoResponse
impl Unpin for DeviceGetDvfsInfoResponse
impl UnsafeUnpin for DeviceGetDvfsInfoResponse
impl UnwindSafe for DeviceGetDvfsInfoResponse