pub struct DeviceGetDvfsOperatingPointRequest {
pub power_domain: PowerDomain,
}Fields
power_domain: PowerDomainTrait Implementations
Sourceimpl Clone for DeviceGetDvfsOperatingPointRequest
impl Clone for DeviceGetDvfsOperatingPointRequest
Sourcefn clone(&self) -> DeviceGetDvfsOperatingPointRequest
fn clone(&self) -> DeviceGetDvfsOperatingPointRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for DeviceGetDvfsOperatingPointRequest
Sourceimpl<D: ResourceDialect> Decode<DeviceGetDvfsOperatingPointRequest, D> for DeviceGetDvfsOperatingPointRequest
impl<D: ResourceDialect> Decode<DeviceGetDvfsOperatingPointRequest, D> for DeviceGetDvfsOperatingPointRequest
Sourceimpl<D: ResourceDialect> Encode<DeviceGetDvfsOperatingPointRequest, D> for &DeviceGetDvfsOperatingPointRequest
impl<D: ResourceDialect> Encode<DeviceGetDvfsOperatingPointRequest, D> for &DeviceGetDvfsOperatingPointRequest
Sourceimpl<D: ResourceDialect, T0: Encode<PowerDomain, D>> Encode<DeviceGetDvfsOperatingPointRequest, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<PowerDomain, D>> Encode<DeviceGetDvfsOperatingPointRequest, D> for (T0,)
impl Eq for DeviceGetDvfsOperatingPointRequest
Sourceimpl Ord for DeviceGetDvfsOperatingPointRequest
impl Ord for DeviceGetDvfsOperatingPointRequest
Sourcefn cmp(&self, other: &DeviceGetDvfsOperatingPointRequest) -> Ordering
fn cmp(&self, other: &DeviceGetDvfsOperatingPointRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceGetDvfsOperatingPointRequest
impl PartialEq for DeviceGetDvfsOperatingPointRequest
Sourcefn eq(&self, other: &DeviceGetDvfsOperatingPointRequest) -> bool
fn eq(&self, other: &DeviceGetDvfsOperatingPointRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceGetDvfsOperatingPointRequest
impl PartialOrd for DeviceGetDvfsOperatingPointRequest
impl Persistable for DeviceGetDvfsOperatingPointRequest
impl StructuralPartialEq for DeviceGetDvfsOperatingPointRequest
Sourceimpl TypeMarker for DeviceGetDvfsOperatingPointRequest
impl TypeMarker for DeviceGetDvfsOperatingPointRequest
Sourcetype Owned = DeviceGetDvfsOperatingPointRequest
type Owned = DeviceGetDvfsOperatingPointRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for DeviceGetDvfsOperatingPointRequest
impl ValueTypeMarker for DeviceGetDvfsOperatingPointRequest
Sourcetype Borrowed<'a> = &'a DeviceGetDvfsOperatingPointRequest
type Borrowed<'a> = &'a DeviceGetDvfsOperatingPointRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for DeviceGetDvfsOperatingPointRequest
impl RefUnwindSafe for DeviceGetDvfsOperatingPointRequest
impl Send for DeviceGetDvfsOperatingPointRequest
impl Sync for DeviceGetDvfsOperatingPointRequest
impl Unpin for DeviceGetDvfsOperatingPointRequest
impl UnsafeUnpin for DeviceGetDvfsOperatingPointRequest
impl UnwindSafe for DeviceGetDvfsOperatingPointRequest