#[repr(C)]pub struct DeviceSetDvfsOperatingPointResponse {
pub status: i32,
}Fields
status: i32Trait Implementations
Sourceimpl Clone for DeviceSetDvfsOperatingPointResponse
impl Clone for DeviceSetDvfsOperatingPointResponse
Sourcefn clone(&self) -> DeviceSetDvfsOperatingPointResponse
fn clone(&self) -> DeviceSetDvfsOperatingPointResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for DeviceSetDvfsOperatingPointResponse
Sourceimpl<D: ResourceDialect> Decode<DeviceSetDvfsOperatingPointResponse, D> for DeviceSetDvfsOperatingPointResponse
impl<D: ResourceDialect> Decode<DeviceSetDvfsOperatingPointResponse, D> for DeviceSetDvfsOperatingPointResponse
Sourceimpl<D: ResourceDialect> Encode<DeviceSetDvfsOperatingPointResponse, D> for &DeviceSetDvfsOperatingPointResponse
impl<D: ResourceDialect> Encode<DeviceSetDvfsOperatingPointResponse, D> for &DeviceSetDvfsOperatingPointResponse
Sourceimpl<D: ResourceDialect, T0: Encode<i32, D>> Encode<DeviceSetDvfsOperatingPointResponse, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<i32, D>> Encode<DeviceSetDvfsOperatingPointResponse, D> for (T0,)
impl Eq for DeviceSetDvfsOperatingPointResponse
Sourceimpl Ord for DeviceSetDvfsOperatingPointResponse
impl Ord for DeviceSetDvfsOperatingPointResponse
Sourcefn cmp(&self, other: &DeviceSetDvfsOperatingPointResponse) -> Ordering
fn cmp(&self, other: &DeviceSetDvfsOperatingPointResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceSetDvfsOperatingPointResponse
impl PartialEq for DeviceSetDvfsOperatingPointResponse
Sourcefn eq(&self, other: &DeviceSetDvfsOperatingPointResponse) -> bool
fn eq(&self, other: &DeviceSetDvfsOperatingPointResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceSetDvfsOperatingPointResponse
impl PartialOrd for DeviceSetDvfsOperatingPointResponse
impl Persistable for DeviceSetDvfsOperatingPointResponse
impl StructuralPartialEq for DeviceSetDvfsOperatingPointResponse
Sourceimpl TypeMarker for DeviceSetDvfsOperatingPointResponse
impl TypeMarker for DeviceSetDvfsOperatingPointResponse
Sourcetype Owned = DeviceSetDvfsOperatingPointResponse
type Owned = DeviceSetDvfsOperatingPointResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for DeviceSetDvfsOperatingPointResponse
impl ValueTypeMarker for DeviceSetDvfsOperatingPointResponse
Sourcetype Borrowed<'a> = &'a DeviceSetDvfsOperatingPointResponse
type Borrowed<'a> = &'a DeviceSetDvfsOperatingPointResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for DeviceSetDvfsOperatingPointResponse
impl RefUnwindSafe for DeviceSetDvfsOperatingPointResponse
impl Send for DeviceSetDvfsOperatingPointResponse
impl Sync for DeviceSetDvfsOperatingPointResponse
impl Unpin for DeviceSetDvfsOperatingPointResponse
impl UnsafeUnpin for DeviceSetDvfsOperatingPointResponse
impl UnwindSafe for DeviceSetDvfsOperatingPointResponse