pub struct DeviceSetTripCelsiusRequest {
pub id: u32,
pub temp: f32,
}Fields
id: u32temp: f32Trait Implementations
Sourceimpl Clone for DeviceSetTripCelsiusRequest
impl Clone for DeviceSetTripCelsiusRequest
Sourcefn clone(&self) -> DeviceSetTripCelsiusRequest
fn clone(&self) -> DeviceSetTripCelsiusRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for DeviceSetTripCelsiusRequest
Sourceimpl Debug for DeviceSetTripCelsiusRequest
impl Debug for DeviceSetTripCelsiusRequest
Sourceimpl<D: ResourceDialect> Decode<DeviceSetTripCelsiusRequest, D> for DeviceSetTripCelsiusRequest
impl<D: ResourceDialect> Decode<DeviceSetTripCelsiusRequest, D> for DeviceSetTripCelsiusRequest
Sourceimpl<D: ResourceDialect> Encode<DeviceSetTripCelsiusRequest, D> for &DeviceSetTripCelsiusRequest
impl<D: ResourceDialect> Encode<DeviceSetTripCelsiusRequest, D> for &DeviceSetTripCelsiusRequest
Sourceimpl<D: ResourceDialect, T0: Encode<u32, D>, T1: Encode<f32, D>> Encode<DeviceSetTripCelsiusRequest, D> for (T0, T1)
impl<D: ResourceDialect, T0: Encode<u32, D>, T1: Encode<f32, D>> Encode<DeviceSetTripCelsiusRequest, D> for (T0, T1)
Sourceimpl PartialEq for DeviceSetTripCelsiusRequest
impl PartialEq for DeviceSetTripCelsiusRequest
Sourcefn eq(&self, other: &DeviceSetTripCelsiusRequest) -> bool
fn eq(&self, other: &DeviceSetTripCelsiusRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DeviceSetTripCelsiusRequest
impl PartialOrd for DeviceSetTripCelsiusRequest
impl Persistable for DeviceSetTripCelsiusRequest
impl StructuralPartialEq for DeviceSetTripCelsiusRequest
Sourceimpl TypeMarker for DeviceSetTripCelsiusRequest
impl TypeMarker for DeviceSetTripCelsiusRequest
Sourcetype Owned = DeviceSetTripCelsiusRequest
type Owned = DeviceSetTripCelsiusRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for DeviceSetTripCelsiusRequest
impl ValueTypeMarker for DeviceSetTripCelsiusRequest
Sourcetype Borrowed<'a> = &'a DeviceSetTripCelsiusRequest
type Borrowed<'a> = &'a DeviceSetTripCelsiusRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for DeviceSetTripCelsiusRequest
impl RefUnwindSafe for DeviceSetTripCelsiusRequest
impl Send for DeviceSetTripCelsiusRequest
impl Sync for DeviceSetTripCelsiusRequest
impl Unpin for DeviceSetTripCelsiusRequest
impl UnsafeUnpin for DeviceSetTripCelsiusRequest
impl UnwindSafe for DeviceSetTripCelsiusRequest