pub struct ThermalInfo {
pub state: u32,
pub passive_temp_celsius: f32,
pub critical_temp_celsius: f32,
pub max_trip_count: u32,
pub active_trip: [f32; 16],
}Expand description
Temperature units are degrees Celsius.
Fields
state: u32State is a bitmask of THERMAL_STATE_* values.
passive_temp_celsius: f32The sensor temperature at which the system should activate passive cooling policy.
critical_temp_celsius: f32The sensor temperature at which the system should perform critical shutdown.
max_trip_count: u32The number of trip points supported.
active_trip: [f32; 16]The currently active trip point.